/**********************************************************************

    Standard simulation of thr Maier-Stein nonequilibrium system.   
    
    For background on this system, and further references see
        "Irreversibility of classical fluctuations studied in analogue 
            electrical circuits"
    D.G. Luchinsky, P.V.E. McClintock, Nature v389 p463 (1997)
    
    The integrator is based on exaple code donated by Dmitrii G Luchinsky.
    
    
    8/98 Gavin Crooks   gavinc@garnet.berkeley.edu
                        http://gold.cchem.berkeley.edu/~gavinc

**********************************************************************/

#include <stdio.h>
#include <math.h>

/* Random Number Generator.
 *  genRanGaussian() returns a double drawn from
 *  a Gaussian distribution of unit varience.
 */
#include "genRan.h"                     


/* System paremeters */
#define D       (0.05)                      /*Variance of fluctuating force*/
#define alpha   (1.)
#define mu      (1.)                

#define TIME        (16)                    /*Total time */
#define TSTEPSPER   (512)                   /*Time steps per time unit */
#define TSTEP       (1./TSTEPSPER)          /*time per time step*/

#define SAMPLES     1000                    /*Number of samples */

/*******************************/
main()
{
    double  x;
    double  y;
    double  grx,gry;
    double x2,xa,ya,xf,yf;
    int samples;
    int t;
    
    for(samples=0;samples<SAMPLES;samples++)
    {
        
        x=1.0;
        y=0.0;
        t=0;
        
        do  
        {
            t++;
            grx =sqrt(D*TSTEP)*genRanGaussian(); 
            gry =sqrt(D*TSTEP)*genRanGaussian(); 
        
            x2 =x*x;
            xa = x + TSTEP*x*(1.-x2-alpha*y*y) + grx;
            ya = y - TSTEP*mu*(1.+x2)*y +gry;
        
            x2 = xa*xa;
            xf = x + TSTEP*xa*(1.-x2-alpha*ya*ya) + grx;
            yf = y - TSTEP*mu*(1.+x2)*ya +gry;
        
            x =(xf+xa)/2.;
            y =(yf+ya)/2.;

        }while(x>0.0); 		/* Stop when path crosses barrier */
        
        printf("%d\t%lg\t%lg\n",t,x,y);
        fflush(stdout);
    }
}

